<?php

/**
 * Gestion de l'action pour peupler spip_gis
 *
 * @plugin Subdivisions
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Action pour peupler la base de données 
 * d'une forme liée à une subdivision.
 * La table d'accueil est spip_gis.
 * Un lien est établit entre spip_gis et la subdivision 
 * avec la table de lien spip_gis_liens.
 *
 * Les arguments attendus 
 *
 * @param string $arg
 *	id_subdivision
 *	type de forme	
 *		
 * @return void
 */
 
function action_subdivision_peupler_dist ($arg = null) {
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}

	// acquision des arguments
	$arg = explode("-", $arg);
	list($id_subdivision,$type_forme) = $arg;

	// vérifications de la validité des arguments
	if (!intval($id_subdivision)) return;
	if (!in_array($type_forme,array('definition'))) return;
	
	// vérification que la subdivision ne bénéficie pas déjà d'une forme
	include_spip('inc/apigeo');
	$peuplee = apigeo_trouver_forme($id_subdivision);

	if (!$peuplee) {
		$id_subdivision_api = apigeo_trouver_api($id_subdivision);
		if ($id_subdivision_api) {
			$id_subdivision_api = apigeo_trouver_api ($id_subdivision);
			$url = apigeo_construire_requete($id_subdivision_api);

			// chargement des polygons envoyés par l'API (retour : json)
			include_spip('inc/distant');
			$json = recuperer_page($url);
	
			// extraction des informations pertinentes (retour : json)
			$objet = apigeo_extraire ($id_subdivision_api,$json);

			// enregistrements dans la base de données (retour : id_gis si réussis false dans le cas contraire)
			$id_gis = apigeo_peupler($objet, $id_subdivision);
			
			// L'utilisateur s'attend à voir l'objet enregistré.
 			$gis_config = lire_config('gis/gis_objets', array());
 			if (!in_array('spip_subdivisions', $gis_config)) { // La config de GIS, doit permettre cette visualisation.
				$gis_config[] = 'spip_subdivisions';
				ecrire_config('gis/gis_objets', $gis_config);
			// L'objet doit être réactualiser pour permettre l'apparition du contour
			// Invalider les caches
			include_spip('inc/invalideur');
			suivre_invalideur("id='id_subdivision/$id_subdivision'");
			}
		} else {
			spip_log("action_subdivision_peupler_dist. id_subdivision n°$id_subdivision n'a pas d'API.",
				 'subdivisions.' . _LOG_INFO_IMPORTANTE);
		}
	} else { 
		spip_log("action_subdivision_peupler_dist. id_subdivision n°$id_subdivision déjà peuplée.",
			 'subdivisions.' . _LOG_INFO_IMPORTANTE);
	}
}
