<?php
/**
 * Gestion du formulaire de d'édition d'une subdivision
 *
 * @plugin     Subdivisions Géographiques
 * @copyright  2020
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Subdivisions\Formulaires
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/actions');
include_spip('inc/editer');

/**
 * Un simple formulaire de déclaration des saisies
 *
 * Utilisation du plugin Saisies
 *
 * @return array
 *     tableau décrivant les saisies à afficher dans le formulaire de configuration
 **/
 
function formulaires_subdivision_saisies($pays, $type_edition, $type_icone, $icone_objet = ''){
	$saisies = array(
		array( // le fieldset principal
			'saisie' => 'fieldset',
			'options' => array(
				'nom' => 'la_subdivision',
				'label' => $type_edition,
				'icone' => $type_icone,
			),
    		'saisies' => array( // les champs dans le fieldset 
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'id_subdivision'
					)
				),
				array( 
					'saisie' => 'hidden',
					'options' => array(
					'nom' => 'retour',
					)
				),
				array( // A-t-on demandé que cette subdivision soit associée à un objet (lors de sa création) ? Cas rare.
					'saisie' => 'hidden',
					'options' => array(
						'nom' => 'associer_objet'
					)
				),
				array( 
					'saisie' => 'textarea',
					'options' => array(
						'nom' => 'titre',
						'label' => _T('subdivision:label_titre_edition'),
						'obligatoire' => 'oui',
 						'placeholder' => '&lt;multi&gt;[fr]en français[en]in english</multi>',
						'conteneur_class' => 'pleine_largeur'
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'nom_usage',
						'conteneur_class' => 'pleine_largeur',
						'label' => _T('subdivision:label_nom_usage'),
 						'placeholder' => '&lt;multi&gt;[fr]en français[en]in english</multi>',
						'explication' => _T('subdivision:label_nom_usage_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'iso_moi',
						'label' => _T('subdivision:label_iso_moi'),
						'explication' => _T('subdivision:label_iso_moi_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'specifique',
						'label' => _T('subdivision:label_specifique'),
						'explication' => _T('subdivision:label_specifique_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'iso_parent',
						'label' => _T('subdivision:label_iso_parent'),
						'explication' => _T('subdivision:label_iso_parent_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'iso_pays',
						'label' => _T('subdivision:label_iso_pays'),
						'explication' => _T('subdivision:label_iso_pays_explication')
					)
				),
				array(
					'saisie' => 'input',
					'options' => array(
						'nom' => 'nuts',
						'label' => _T('subdivision:label_nuts'),
						'explication' => _T('subdivision:label_nuts_explication')
					)
				)
			)
		),
		array( // le fieldset d'association 
			'saisie' => 'fieldset',
			'options' => array(
				'afficher_si'=> '@associer_objet@ != ""',
				'nom' => 'lassociation',
				'label' => _T('subdivision:label_lassociation'),
				'icone' => $icone_objet
			),
			'saisies' => array( // les champs dans le second fieldset 
				array(
					'saisie' => 'case',
					'options' => array(
						'nom' => 'c_associe',
						'label_case' => _T('subdivision:texte_associer_subdivision'),
						'conteneur_class' => 'pleine_largeur'
					)
				)
			)
		)
	);

	return $saisies;
}

/**
 * Identifier le formulaire en faisant abstraction des paramètres qui ne représentent pas l'objet édité
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return string
 *     Hash du formulaire
 */
function formulaires_editer_subdivision_identifier_dist($id_subdivision = 'new', $id_pays = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	return serialize(array(intval($id_pensebete), $associer_objet));
}

/**
 * Chargement du formulaire d'édition de subdivision
 *
 * Déclarer les champs postés et y intégrer les valeurs par défaut
 *
 * @uses formulaires_editer_objet_charger()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour une nouvelle subdivision.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Environnement du formulaire
 */
function formulaires_editer_subdivision_charger_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {

	$valeurs = formulaires_editer_objet_charger('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	$type_icone = "subdivision-edit-16.png";
	$type_edition = _T('subdivision:icone_modifier_subdivision');

	if ($valeurs['id_subdivision'] == 'oui') {
		$type_icone = "subdivision-new-16.png";
		$type_edition = _T('subdivision:icone_creer_subdivision');
	}
	$valeurs['retour'] = $retour;

	// A-t-on demandé à ce que la subdivision soit associée à un objet éditorial ?
	if ($associer_objet) {
		$valeurs['associer_objet'] = $associer_objet;
		list($objet, $id_objet) = explode('|', $associer_objet);
		$icone_objet = chemin_image($objet);
		$valeurs['c_associe'] = 'on';
		$type_icone = "subdivision-new-link-16.png";
		$type_edition = _T('subdivision:texte_creer_associer_subdivision');
	} else
		$valeurs['c_associe'] = '';

	// selon l'existence du plugin Pays et de sa saisie, nourrir la déclaration des saisies.

	if (test_plugin_actif('pays')) {
		$pays =	array(
			'saisie' => 'pays',
			'options' => array(
				'nom' => 'iso_pays',
				'label' => _T('pays:titre_pays'),
				'cacher_option_intro' => 'oui',
				//'champ_pays' => 'id_pays'
			),
		);
	} else {
		$pays =	array(
			'saisie' => 'input',
			'options' => array(
				'nom' => 'iso_pays',
				'label' => _T('subdivision:label_iso_pays'),
				'explication' => _T('subdivision:label_iso_pays_explication'),
			),
		);
	}


	// transmettre les listes au plugin Saisies pour formulaires

	$valeurs['_mes_saisies'] = formulaires_subdivision_saisies($pays, $type_edition, $type_icone, $icone_objet);
	
	return $valeurs;
}

/**
 * Vérifications du formulaire d'édition de subdivision
 *
 * Vérifier les champs postés et signaler d'éventuelles erreurs
 *
 * @uses formulaires_editer_objet_verifier()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Tableau des erreurs
 */
function formulaires_editer_subdivision_verifier_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	$erreurs = array();

	//$erreurs = formulaires_editer_objet_verifier('subdivision', $id_subdivision, array('id_subdivision', 'titre'));

	return $erreurs;
}

/**
 * Traitement du formulaire d'édition de subdivision
 *
 * Traiter les champs postés
 *
 * @uses formulaires_editer_objet_traiter()
 *
 * @param int|string $id_subdivision
 *     Identifiant de la subdivision. 'new' pour un nouveau paiement.
 * @param int $id_parent
 *     Identifiant de l'objet parent (si connu) - ici inutile
 * @param string $retour
 *     URL de redirection après le traitement
 * @param int $lier_trad
 *     Identifiant éventuel d'une nouvelle subdivision source d'une traduction (inutile nous sommes en multi)
 * @param string $config_fonc
 *     Nom de la fonction ajoutant des configurations particulières au formulaire
 * @param array $row
 *     Valeurs de la ligne SQL du paiement, si connu
 * @param string $hidden
 *     Contenu HTML ajouté en même temps que les champs cachés du formulaire.
 * @return array
 *     Retours des traitements
 */
function formulaires_editer_subdivision_traiter_dist($id_subdivision = 'new', $id_parent = 0, $retour = '', $associer_objet, $lier_trad = 0, $config_fonc = '', $row = array(), $hidden = '') {
	//if (_request('id_subdivision')==0) // vous pouvez indiquer que vous ne voulez pas que l'auteur soit lié à la région.
		//set_request('id_auteur','');   // objet_inserer va chercher l'information en un _request('id_auteur')
		//voir si on ne met pas une config pour cela.

	// rompre l'association si nécessaire		
	if (_request('c_associe')==''){
		set_request('associer_objet','');
	} else { // on garde la donnée de redirection s'il y a une association
		$redirect=_request('redirect');
	}

	$retours = formulaires_editer_objet_traiter('subdivision', $id_subdivision, $id_parent, $lier_trad, $retour, $config_fonc, $row, $hidden);
	
	// associer la subdivision à un objet
	if (_request('associer_objet') AND $id_subdivision = $retours['id_subdivision']) {			
		if (intval(_request('associer_objet'))) {
				// compat avec l'appel de la forme ajouter_id_article
				$objet = 'article';
				$id_objet = intval(_request('associer_objet'));
		} else {
				list($objet, $id_objet) = explode('|', _request('associer_objet'));
		}
		if ($objet and $id_objet and autoriser('modifier', $objet, $id_objet)) {
			include_spip('action/editer_liens');
			objet_associer( array('subdivision' => $id_subdivision), array($objet => $id_objet) );
			// rediriger vers l'objet
			if (isset($redirect)) {
				$retours['redirect'] = parametre_url($redirect, 'id_lien_ajoute', $id_subdivision, '&');
			}
			return $retours;
		}
		else
			return array('message_erreur'=>_T('subdivision:erreur_association'));
	} // si remord par rapport à l'association à l'objet, rediriger vers la subdivision
	elseif (_request('c_associe')=='non')
		$retours['redirect']=generer_url_ecrire('subdivision','id_subdivision='.$retours['id_subdivision']);
	
	
	return $retours;
}
